@@ -153,6 +153,7 @@ typedef struct r_cons_palette_t {
 	char *cjmp;
 	char *cmp;
 	char *comment;
+	char *usercomment;
 	char *creg;
 	char *flag;
 	char *fline;
@@ -328,7 +329,7 @@ typedef struct r_cons_t {
 #if __UNIX__ || __CYGWIN__ && !defined(MINGW32)
 	struct termios term_raw, term_buf;
 #elif __WINDOWS__
-	LPDWORD term_raw, term_buf;
+	DWORD term_raw, term_buf;
 #endif
 	RNum *num;
 	/* Pager (like more or less) to use if the output doesn't fit on the
