@@ -22,6 +22,10 @@
 
 #define R_IO_UNDOS 64
 
+#if __cplusplus
+extern "C" {
+#endif
+
 R_LIB_VERSION_HEADER(r_io);
 
 typedef struct r_io_undos_t {
@@ -137,7 +141,7 @@ typedef struct r_io_plugin_t {
 	RIOUndo undo;
 	bool isdbg;
 	// int (*is_file_opened)(RIO *io, RIODesc *fd, const char *);
-	int (*system)(RIO *io, RIODesc *fd, const char *);
+	char *(*system)(RIO *io, RIODesc *fd, const char *);
 	RIODesc* (*open)(RIO *io, const char *, int rw, int mode);
 	RList* /*RIODesc* */ (*open_many)(RIO *io, const char *, int rw, int mode);
 	int (*read)(RIO *io, RIODesc *fd, ut8 *buf, int count);
@@ -234,7 +238,7 @@ typedef bool (*RIOClose) (RIO *io, int fd);
 typedef bool (*RIOReadAt) (RIO *io, ut64 addr, ut8 *buf, int len);
 typedef RIOAccessLog *(*RIOAlReadAt) (RIO *io, ut64 addr, ut8 *buf, int len);
 typedef bool (*RIOWriteAt) (RIO *io, ut64 addr, const ut8 *buf, int len);
-typedef int (*RIOSystem) (RIO *io, const char* cmd);
+typedef char *(*RIOSystem) (RIO *io, const char* cmd);
 typedef int (*RIOFdOpen) (RIO *io, const char *uri, int flags, int mode);
 typedef bool (*RIOFdClose) (RIO *io, int fd);
 typedef ut64 (*RIOFdSeek) (RIO *io, int fd, ut64 addr, int whence);
@@ -334,7 +338,7 @@ R_API bool r_io_read (RIO *io, ut8 *buf, int len);
 R_API bool r_io_write (RIO *io, ut8 *buf, int len);
 R_API ut64 r_io_size (RIO *io);
 R_API bool r_io_is_listener (RIO *io);
-R_API int r_io_system (RIO *io, const char* cmd);
+R_API char *r_io_system (RIO *io, const char* cmd);
 R_API bool r_io_resize (RIO *io, ut64 newsize);
 R_API int r_io_extend_at (RIO *io, ut64 addr, ut64 size);
 R_API bool r_io_set_write_mask (RIO *io, const ut8 *mask, int len);
@@ -352,6 +356,7 @@ R_API int r_io_plugin_close(RIO *io, int fd, RIOPlugin *plugin);
 R_API int r_io_plugin_generate(RIO *io);
 R_API bool r_io_plugin_add(RIO *io, RIOPlugin *plugin);
 R_API int r_io_plugin_list(RIO *io);
+R_API int r_io_plugin_list_json(RIO *io);
 R_API RIOPlugin *r_io_plugin_resolve(RIO *io, const char *filename, bool many);
 R_API RIOPlugin *r_io_plugin_resolve_fd(RIO *io, int fd);
 R_API RIOPlugin *r_io_plugin_get_default(RIO *io, const char *filename, bool many);
@@ -523,4 +528,8 @@ extern RIOPlugin r_io_plugin_ar;
 extern RIOPlugin r_io_plugin_rbuf;
 extern RIOPlugin r_io_plugin_winedbg;
 
+#if __cplusplus
+}
+#endif
+
 #endif
