@@ -1,7 +1,21 @@
 #ifndef R_STR_H
 #define R_STR_H
 
+#include <wchar.h>
 #include "r_str_util.h"
+#include "r_list.h"
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+typedef enum {
+	R_STRING_ENC_LATIN1 = 'a',
+	R_STRING_ENC_UTF8 = '8',
+	R_STRING_ENC_UTF16LE = 'u',
+	R_STRING_ENC_UTF32LE = 'U',
+	R_STRING_ENC_GUESS = 'g',
+} RStrEnc;
 
 typedef int (*RStrRangeCallback) (void *, int);
 
@@ -13,6 +27,7 @@ static inline void r_str_rmch(char *s, char ch) {
 }
 #define r_str_array(x,y) ((y>=0 && y<(sizeof(x)/sizeof(*x)))?x[y]:"")
 R_API const char *r_str_pad(const char ch, int len);
+R_API const char *r_str_rstr(const char *base, const char *p);
 R_API const char *r_str_rchr(const char *base, const char *p, int ch);
 R_API const char *r_str_closer_chr(const char *b, const char *s);
 R_API int r_str_bounds(const char *str, int *h);
@@ -28,6 +43,7 @@ R_API const char *r_str_casestr(const char *a, const char *b);
 R_API const char *r_str_firstbut(const char *s, char ch, const char *but);
 R_API const char *r_str_lastbut(const char *s, char ch, const char *but);
 R_API int r_str_split(char *str, char ch);
+R_API RList *r_str_split_list(char *str);
 R_API int *r_str_split_lines(char *str, int *count);
 R_API char* r_str_replace(char *str, const char *key, const char *val, int g);
 R_API char *r_str_replace_in(char *str, ut32 sz, const char *key, const char *val, int g);
@@ -44,6 +60,7 @@ R_API char *r_str_arg_escape(const char *arg);
 R_API char **r_str_argv(const char *str, int *_argc);
 R_API void r_str_argv_free(char **argv);
 R_API char *r_str_new(const char *str);
+R_API bool r_str_is_ascii(const char *str);
 R_API int r_str_is_printable(const char *str);
 R_API bool r_str_is_printable_incl_newlines(const char *str);
 R_API char *r_str_appendlen(char *ptr, const char *string, int slen);
@@ -88,22 +105,29 @@ R_API int r_str_inject(char *begin, char *end, char *str, int maxlen);
 R_API int r_str_delta(char *p, char a, char b);
 R_API void r_str_filter(char *str, int len);
 R_API const char * r_str_tok(const char *str1, const char b, size_t len);
+R_API wchar_t *r_str_mb_to_wc(const char *buf);
+R_API char *r_str_wc_to_mb(const wchar_t *buf);
+R_API wchar_t *r_str_mb_to_wc_l(const char *buf, int len);
+R_API char *r_str_wc_to_mb_l(const wchar_t *buf, int len);
 
 typedef void(*str_operation)(char *c);
 
 R_API int r_str_do_until_token(str_operation op, char *str, const char tok);
 
-R_API void r_str_const_free(void);
 R_API const char *r_str_const(const char *ptr);
+R_API const char *r_str_const_at(char ***consts, const char *ptr);
+R_API void r_str_const_free(char ***consts);
 
+R_API void r_str_reverse(char *str);
 R_API int r_str_re_match(const char *str, const char *reg);
 R_API int r_str_re_replace(const char *str, const char *reg, const char *sub);
 R_API int r_str_unescape(char *buf);
 R_API char *r_str_escape(const char *buf);
 R_API char *r_str_escape_dot(const char *buf);
-R_API char *r_str_escape_asciidot(const char *buf);
-R_API char *r_str_escape_latin1(const char *buf);
-R_API char *r_str_escape_utf8(const char *buf);
+R_API char *r_str_escape_latin1(const char *buf, bool show_asciidot, bool esc_bslash);
+R_API char *r_str_escape_utf8(const char *buf, bool show_asciidot, bool esc_bslash);
+R_API char *r_str_escape_utf16le(const char *buf, int buf_size, bool show_asciidot);
+R_API char *r_str_escape_utf32le(const char *buf, int buf_size, bool show_asciidot);
 R_API void r_str_uri_decode(char *buf);
 R_API char *r_str_uri_encode(const char *buf);
 R_API char *r_str_utf16_decode(const ut8 *s, int len);
@@ -133,5 +157,10 @@ R_API bool r_str_endswith(const char *str, const char *needle);
 R_API bool r_str_isnumber (const char *str);
 R_API const char *r_str_last (const char *in, const char *ch);
 R_API char* r_str_highlight(char *str, const char *word, const char *color);
+R_API char *r_qrcode_gen(const ut8 *text, int len, bool utf8, bool inverted);
+R_API char *r_str_from_ut64(ut64 val);
+#ifdef __cplusplus
+}
+#endif
 
 #endif //  R_STR_H
